@@ -40,14 +40,6 @@ from .config import (
 
 class PrometheusMiddleware(metaclass=SingletonMeta):
 
-    # NOTE: percentile for summary -> https://www.mail-archive.com/prometheus-users@googlegroups.com/msg08275.html
-    # TODO: check async for fastapi
-    # DONE: add readme.md and ..
-    # DONE: add test for bracket
-    # DONE: check read env
-    # os.environ['SERVICE_NAME_PREFIX']
-    # DONE: add warn seperately -> Please provide SERVICE_NAME_PREFIX and SERVICE_NAME in .env file
-
     namespace = NAMESPACE
     service_name = SERVICENAME
 
@@ -351,8 +343,8 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
         self.app.add_middleware(MetricsRedirect)
         self.app.mount("/metrics", WSGIMiddleware(make_wsgi_app()))
 
-        # NOTE: loop through all endpoint and get path_format
         def get_path_format(app_routes, path):
+            """loop through all endpoint to get parh_format"""
             path_format = path
             for route in app_routes:
                 if re.search(route.path_regex, path) is not None:
@@ -361,9 +353,12 @@ class PrometheusMiddleware(metaclass=SingletonMeta):
 
         def fastapi_after_request(response, request):
             # path_format = get_path_format(request.app.routes, request.url.path)
-            path_format = get_path_format(
-                request.app.routes, request.scope.get("path", request.url.path)
+            request_path = request.scope.get("raw_path")
+            request_path = (
+                request_path.decode("utf-8") if request_path else request.url.path
             )
+
+            path_format = get_path_format(request.app.routes, request_path)
             if not self.is_exclude(request.method, path_format, response.status_code):
                 request_latency = (
                     time.time() - request._prometheus_metrics_request_start_time
